package com.ruoyi.model.mapper;

import java.util.List;
import com.ruoyi.model.domain.CurrentConfig;

/**
 * 等级配置Mapper接口
 * 
 * @author ruoyi
 * @date 2025-03-05
 */
public interface CurrentConfigMapper 
{
    /**
     * 查询等级配置
     * 
     * @param currentId 等级配置主键
     * @return 等级配置
     */
    public CurrentConfig selectCurrentConfigByCurrentId(Long currentId);

    /**
     * 查询等级配置列表
     * 
     * @param currentConfig 等级配置
     * @return 等级配置集合
     */
    public List<CurrentConfig> selectCurrentConfigList(CurrentConfig currentConfig);

    /**
     * 新增等级配置
     * 
     * @param currentConfig 等级配置
     * @return 结果
     */
    public int insertCurrentConfig(CurrentConfig currentConfig);

    /**
     * 修改等级配置
     * 
     * @param currentConfig 等级配置
     * @return 结果
     */
    public int updateCurrentConfig(CurrentConfig currentConfig);

    /**
     * 删除等级配置
     * 
     * @param currentId 等级配置主键
     * @return 结果
     */
    public int deleteCurrentConfigByCurrentId(Long currentId);

    /**
     * 批量删除等级配置
     * 
     * @param currentIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCurrentConfigByCurrentIds(Long[] currentIds);

    /**
     * 查询等级配置列表
     *
     * @return 等级配置集合
     */
    public List<CurrentConfig> getCurrentConfigList();
}
